# Single-cell multi-omics related utilities
This package is specifically designed to the R package: [smmtools](https://github.com/beyondpie/smmtools).

It includes:
- Doublet removement with Scrublet
- Clustering with Leiden algorithm and the corresponding measurements
- Some functions related with [SnapTools](https://github.com/r3fang/SnapTools) to handle Snap files.
